#
# spec file for package virglrenderer
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define         libname lib%{name}0
Name:           virglrenderer
Version:        0.6.0
Release:        lp152.5.1
Summary:        Virgl Rendering library
License:        MIT
Group:          Development/Libraries/C and C++
Url:            https://virgil3d.github.io/
Source0:        https://www.freedesktop.org/software/virgl/virglrenderer-%{version}.tar.bz2
Source1:        https://www.freedesktop.org/software/virgl/virglrenderer-%{version}.tar.bz2.sig
Source2:        %{name}.keyring
# PATCH-FIX-UPSTREAM 0001-737c3350-renderer-fix-memory-leak-in-vertex-elements-state-cr.patch
Patch0001:      0001-737c3350-renderer-fix-memory-leak-in-vertex-elements-state-cr.patch
Patch0002:      0002-5d03711-vrend-Keep-the-max-texture-sizes-in-the-vrend_state.patch
Patch0003:      0003-0d9a2c8-vrend-Check-resource-creation-more-thoroughly.patch
Patch0004:      0004-24f67de-vrend-check-info-formats-in-blits.patch
Patch0005:      0005-cbc8d8b-vrend-check-transfer-bounds-for-negative-values-too-.patch
Patch0006:      0006-2abeb18-vrend-check-that-the-transfer-iov-holds-enough-data-.patch
BuildRequires:  Mesa-devel
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  pkgconfig >= 0.9.0
BuildRequires:  pkgconfig(egl)
BuildRequires:  pkgconfig(epoxy)
BuildRequires:  pkgconfig(gbm)
BuildRequires:  pkgconfig(lbxutil)
BuildRequires:  pkgconfig(libdrm) >= 2.4.50
BuildRequires:  pkgconfig(python2)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xorg-macros) >= 1.8

%description
The virgil3d rendering library is a library used by
qemu to implement 3D GPU support for the virtio GPU.

%package -n %{libname}
Summary:        Virgil3D renderer
Group:          System/Libraries

%description -n %{libname}
The virgil3d rendering library is a library used by
qemu to implement 3D GPU support for the virtio GPU.

%package devel
Summary:        Virgil3D renderer development files
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}

%description devel
The virgil3d rendering library is a library used by
qemu to implement 3D GPU support for the virtio GPU.
This package contains the virgil3d renderer development
files.

%package test-server
Summary:        Virgil3D renderer development files
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}

%description test-server
The virgil3d rendering library is a library used by
qemu to implement 3D GPU support for the virtio GPU.
This package contains a server to test virgl rendering
without GL.

%prep
%setup -q
%patch0001 -p1
%patch0002 -p1
%patch0003 -p1
%patch0004 -p1
%patch0005 -p1
%patch0006 -p1

%build
sed -i -e 's|@CODE_COVERAGE_RULES@| |g' Makefile.am
autoreconf -fi
%configure
make %{?_smp_mflags} V=1

%install
%make_install
rm -f %{buildroot}%{_libdir}/libvirglrenderer.la

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%doc COPYING
%{_libdir}/lib*.so.*

%files devel
%dir %{_includedir}/virgl/
%{_includedir}/virgl/*
%{_libdir}/lib*.so
%{_libdir}/pkgconfig/*.pc

%files test-server
%{_bindir}/virgl_test_server

%changelog
* Fri Dec 20 2019 lma@suse.com
- Add 4 security fixes
  * Check resource creation more thoroughly (CVE-2019-18388 bsc#1159479)
  0002-5d03711-vrend-Keep-the-max-texture-sizes-in-the-vrend_state.patch
  0003-0d9a2c8-vrend-Check-resource-creation-more-thoroughly.patch
  * check info formats in blits (CVE-2019-18390 bsc#1159478)
  0004-24f67de-vrend-check-info-formats-in-blits.patch
  * check transfer bounds for negative values too (CVE-2019-18389 bsc#1159482)
  0005-cbc8d8b-vrend-check-transfer-bounds-for-negative-values-too-.patch
  * check transfer iov holds enough data for the data upload (CVE-2019-18391 bsc#1159486)
  0006-2abeb18-vrend-check-that-the-transfer-iov-holds-enough-data-.patch
* Wed Nov  1 2017 mpluskal@suse.com
- Clean up spec file with spec-cleaner
- Use source url
- Add gpg signature
- Make building more verbose
- Explicitly require python2
* Fri Mar 10 2017 lma@suse.com
- Fix memory leak in vertex elements state create (CVE-2017-6386 bsc#1027376)
  0001-737c3350-renderer-fix-memory-leak-in-vertex-elements-state-cr.patch
* Thu Mar  2 2017 jengelh@inai.de
- Fix RPM groups
* Fri Feb 24 2017 lma@suse.com
- Update package to 0.6.0
  The following patches will be removed:
  0001-48f67f60-renderer-fix-NULL-pointer-deref-in-vrend_clear.patch
  0002-40b0e781-renderer-fix-a-leak-in-resource-attach.patch
  0003-6eb13f7a-vrend-fix-memory-leak-in-int-blit-context.patch
  0004-114688c5-renderer-fix-heap-overflow-in-vertex-elements-state-.patch
  0005-926b9b34-vrend-fix-a-stack-overflow-in-set-framebuffer-state.patch
  All of the removed patches were already included in 0.6.0,
  So we dont need them any more.
* Fri Feb 17 2017 lma@suse.com
- Address various security issues
  * Fix null pointer dereference in vrend_clear (CVE-2017-5937 bsc#1024232)
  0001-48f67f60-renderer-fix-NULL-pointer-deref-in-vrend_clear.patch
  * Fix host memory leak issue in virgl_resource_attach_backing (CVE-2016-10214 bsc#1024244)
  0002-40b0e781-renderer-fix-a-leak-in-resource-attach.patch
  * Fix memory leak in int blit context (CVE-2017-5993 bsc#1025505)
  0003-6eb13f7a-vrend-fix-memory-leak-in-int-blit-context.patch
  * Fix heap overflow in vertex elements state create (CVE-2017-5994 bsc#1025507)
  0004-114688c5-renderer-fix-heap-overflow-in-vertex-elements-state-.patch
  * Fix a stack overflow in set framebuffer state (CVE-2017-5957 bsc#1024993)
  0005-926b9b34-vrend-fix-a-stack-overflow-in-set-framebuffer-state.patch
* Fri Jun  3 2016 brogers@suse.com
- Further tweaks to package layout, including splitting out
  the test server into it's own package.
* Wed Jun  1 2016 brogers@suse.com
- Refine BuildRequires tags
* Thu Apr 14 2016 brogers@suse.com
- Fixed url in spec file
* Wed Apr 13 2016 lma@suse.com
- Fixed epoxy dependency
* Tue Apr 12 2016 lma@suse.com
- Initial package, based upon virglrenderer upstream sources
  (git tag: 0.5.0)
